==> owncloud-8.1.0p2.tgz: owncloud/apps/updater/l10n/es.js <==
OC.L10N.register(
    "updater",
    {
    "Version not found" : "Versión no encontrada",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "No se puede actualizar. Su servidor de internet no tiene permiso para eliminar el siguiente directorio:",
    "Update permissions on this directory and its content or remove it manually first." : "Actualice los permisos de esta carpeta y sus contenidos o elimínela manualmente.",
    "Unable to switch channel." : "Desactivar para cambiar el canal",
    "Update failed." : "Falló la actualización.",
    "Fetching..." : "Trayendo...",
    "<strong>The update was unsuccessful.</strong><br />Please check logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." : "<strong>La actualización ha fallado.</strong><br />Por favor, revise la razón del fallo en el registro de la página de admin e informe de este problema a la <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">comunidad de ownCloud</a>.",
    "<strong>Server error.</strong> Please check web server log file for details" : "<strong>Error en el servidor.</strong> Por favor compruebe los registros del servidor para más detalles",
    "Retry" : "Reintentar",
    "Here is your backup:" : "Aquí está su copia de seguridad:",
    "Proceed" : "Proceder",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Todo listo.</strong> Pulse en el enlace siguiente para iniciar la actualización de la base de datos.",
    "Production" : "Producción",
    "Stable" : "Estable",
    "Beta" : "Beta",
    "Daily" : "Diariamente",
    "Please ask your server administrator to enable PHP zip extension." : "Pídale al administrador del servidor que active la extensión zip de PHP.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "No se puede actualizar %s a %s. Tampoco es posible retroceder a una versión anterior o saltarse una versión importante.",
    "Make sure that your web server has read access to the following files and directories:" : "Asegúrese de que su servidor tenga acceso de lectura a los siguientes archivos y carpetas:",
    "Make sure that your web server has write access to the following files and directories:" : "Asegúrese de que su servidor tenga acceso de escritura a los siguientes archivos y carpetas:",
    "Updates" : "Actualizaciones",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>Una nueva versión está disponible: {{newVersion}}</strong>",
    "Updates will be available in the updater app and ownCloud admin panel within a few days of an update announcement." : "Las actualizaciones estarán disponibles en la aplicación de actualizaciones y en el panel de administración de ownCloud a los pocos dias de ser anunciadas.",
    "<strong>Up to date.</strong> <em>Checked on {{checkedAt}}</em>" : "<strong>Actualizado.</strong> <em>Comprobado el {{checkedAt}}</em>",
    "1. Check & Backup" : "1. Comprobar y resguardar",
    "2. Download & Extract" : "2. Descargar y extraer",
    "3. Replace" : "3. Reemplazar",
    "Update" : "Actualizar",
    "Update channel:" : "Vía de actualización: ",
    "Please note update is possible only to a version that is greater than the one currently installed. If you upgraded from a less stable channel you will be able to upgrade from a more stable channel only after the version that is greater than you installed reaches it." : "Por favor note que la actualización es posible solo a una versión que es posterior que la actualmente instalada. Si se actualizada desde un canal menos estable podrá actualizar a un canal más estable solo después que la versión instalada la alcanza.",
    "Updater-Backups" : "Copia de seguridad del actualizador",
    "Note" : "Nota",
    "Here you can find backups of the core of your ownCloud <strong>(excluding your data)</strong> after starting an update to a newer version." : "Aquí puede encontrar copias de seguridad del núcleo de su ownCloud <strong>(excluyendo los datos)</strong> realizadas al comenzar una actualización a una nueva versión.",
    "<strong>Please always backup your data separately before updating!</strong>" : "<strong>Por favor, ¡siempre realice copia de seguridad de los datos de manera separada antes de actualizar!</strong>",
    "Backup directory" : "Directorio de respaldos",
    "No backups found." : "No se han encontrado copias de seguridad.",
    "Backup" : "Copia de seguridad",
    "Done on" : "Hecho en",
    "Size" : "Tamaño",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Are you sure you want to delete {{entry.title}}" : "¿Está seguro de querer borrar {{entry.title}}"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/updater/l10n/es.js <==
OC.L10N.register(
    "updater",
    {
    "Unable to switch channel." : "Desactivar para cambiar el canal",
    "Version not found" : "Versión no encontrada",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "No se puede actualizar. Su servidor de internet no tiene permiso para eliminar el siguiente directorio:",
    "Update permissions on this directory and its content or remove it manually first." : "Actualice los permisos de esta carpeta y sus contenidos o elimínela manualmente.",
    "Update failed." : "Falló la actualización.",
    "Fetching..." : "Trayendo...",
    "<strong>The update was unsuccessful.</strong><br />Please check the logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." : "<strong>La actualización ha fallado.</strong><br />Por favor, revise el fallo en el registro de la página de administración e informe de este problema a la <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">comunidad de ownCloud</a>.",
    "<strong>Server error.</strong> Please check the web server log file for details." : "<strong>Error en el servidor.</strong> Por favor, compruebe el archivo de registro del servidor para más detalles.",
    "Retry" : "Reintentar",
    "Here is your backup:" : "Aquí está su copia de seguridad:",
    "Proceed" : "Proceder",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Todo listo.</strong> Pulse en el enlace siguiente para iniciar la actualización de la base de datos.",
    "Production" : "Producción",
    "Stable" : "Estable",
    "Beta" : "Beta",
    "Daily" : "Diariamente",
    "Please ask your server administrator to enable PHP zip extension." : "Pídale al administrador del servidor que active la extensión zip de PHP.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "No se puede actualizar %s a %s. Tampoco es posible retroceder a una versión anterior o saltarse una versión importante.",
    "Make sure that your web server has read access to the following files and directories:" : "Asegúrese de que su servidor tenga acceso de lectura a los siguientes archivos y carpetas:",
    "Make sure that your web server has write access to the following files and directories:" : "Asegúrese de que su servidor tenga acceso de escritura a los siguientes archivos y carpetas:",
    "Updates" : "Actualizaciones",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>Una nueva versión está disponible: {{newVersion}}</strong>",
    "Testing is everything: Therefore updates will be available here within a few days after the announcement." : "Testear lo es todo: Por consiguiente las actualizaciones estarán disponibles aquí unos días después del anuncio",
    "<strong>Your version is up to date.</strong>" : "<strong>Su versión está actualizada.</strong>",
    "1. Check & Backup" : "1. Comprobar y resguardar",
    "2. Download & Extract" : "2. Descargar y extraer",
    "3. Replace" : "3. Reemplazar",
    "Update" : "Actualizar",
    "Update channel:" : "Vía de actualización: ",
    "Updater-Backups" : "Copia de seguridad del actualizador",
    "<strong>Important: Please always do a separate backup of database and personal data before updating.</strong>" : "<strong>Importante: Realice siempre una copia de seguridad separada de la base de datos y los datos personales antes de actualizar.</strong>",
    "No backups found." : "No se han encontrado copias de seguridad.",
    "Backup" : "Copia de seguridad",
    "Done on" : "Hecho en",
    "Size" : "Tamaño",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Are you sure you want to delete {{entry.title}}" : "¿Está seguro de querer borrar {{entry.title}}",
    "Backup directory" : "Directorio de respaldos"
},
"nplurals=2; plural=(n != 1);");
